This repository is forked from [conradsnicta/armadillo-code](https://github.com/conradsnicta/armadillo-code) and contains source code of **version 8.5**<br />
Some changes were made to make Armadillo repo smaller. This repository is created for the purpose of building C++ extension module for LightTwinSVM project. <br />


Armadillo: C++ Library for Linear Algebra & Scientific Computing <br />
Armadillo is licensed under the Apache License, Version 2.0 <br />
http://arma.sourceforge.net<br />
http://gitlab.com/conradsnicta/armadillo-code <br />
<br />
Copyright 2008-2018 Conrad Sanderson (http://conradsanderson.id.au) <br />
Copyright 2008-2016 National ICT Australia (NICTA)<br />
Copyright 2017-2018 Arroyo Consortium<br />
Copyright 2017-2018 Data61, CSIRO<br />
